==> selenide-core-6.6.3-sources.jar: com/codeborne/selenide/commands/GetSelectedOptions.java <==
package com.codeborne.selenide.commands;

import com.codeborne.selenide.Command;
import com.codeborne.selenide.Driver;
import com.codeborne.selenide.ElementsCollection;
import com.codeborne.selenide.SelenideElement;
import com.codeborne.selenide.impl.Alias;
import com.codeborne.selenide.impl.CollectionSource;
import com.codeborne.selenide.impl.WebElementSource;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.ui.Select;

import javax.annotation.CheckReturnValue;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;
import java.util.List;

import static com.codeborne.selenide.impl.Alias.NONE;

@ParametersAreNonnullByDefault
public class GetSelectedOptions implements Command<ElementsCollection> {
  @Override
  public ElementsCollection execute(SelenideElement proxy, final WebElementSource selectElement, @Nullable Object[] args) {
    return new ElementsCollection(new SelectedOptionsCollection(selectElement));
  }

  private static class SelectedOptionsCollection implements CollectionSource {
    private final WebElementSource selectElement;
    private Alias alias = NONE;

    private SelectedOptionsCollection(WebElementSource selectElement) {
      this.selectElement = selectElement;
    }

    @Override
    @CheckReturnValue
    @Nonnull
    public List<WebElement> getElements() {
      return select(selectElement).getAllSelectedOptions();
    }

    @Override
    @CheckReturnValue
    @Nonnull
    public WebElement getElement(int index) {
      return index == 0 ?
        select(selectElement).getFirstSelectedOption() :
        select(selectElement).getAllSelectedOptions().get(index);
    }

    @CheckReturnValue
    @Nonnull
    private Select select(WebElementSource selectElement) {
      return new Select(selectElement.getWebElement());
    }

    @Override
    @CheckReturnValue
    @Nonnull
    public String getSearchCriteria() {
      return selectElement.description() + " selected options";
    }

    @Override
    @CheckReturnValue
    @Nonnull
    public Driver driver() {
      return selectElement.driver();
    }

    @Nonnull
    @Override
    public Alias getAlias() {
      return alias;
    }

    @Override
    public void setAlias(String alias) {
      this.alias = new Alias(alias);
    }
  }
}

==> selenide-core-7.11.1-sources.jar: com/codeborne/selenide/commands/GetSelectedOptions.java <==
package com.codeborne.selenide.commands;

import com.codeborne.selenide.Command;
import com.codeborne.selenide.Driver;
import com.codeborne.selenide.ElementsCollection;
import com.codeborne.selenide.SelenideElement;
import com.codeborne.selenide.impl.Alias;
import com.codeborne.selenide.impl.CollectionSource;
import com.codeborne.selenide.impl.WebElementSource;
import org.jspecify.annotations.Nullable;
import org.openqa.selenium.WebElement;

import java.util.List;

import static com.codeborne.selenide.impl.Alias.NONE;
import static java.util.Objects.requireNonNull;

public class GetSelectedOptions implements Command<ElementsCollection> {
  @Override
  public ElementsCollection execute(SelenideElement proxy, final WebElementSource selectElement, Object @Nullable [] args) {
    return new ElementsCollection(new SelectedOptionsCollection(selectElement));
  }

  private static class SelectedOptionsCollection implements CollectionSource {
    private final WebElementSource selectElement;
    private Alias alias = NONE;

    private SelectedOptionsCollection(WebElementSource selectElement) {
      this.selectElement = selectElement;
    }

    @Override
    public List<WebElement> getElements() {
      return requireNonNull(selectElement.driver().executeJavaScript(
        "return arguments[0].selectedOptions", selectElement.getWebElement()
      ));
    }

    @Override
    public WebElement getElement(int index) {
      return requireNonNull(selectElement.driver().executeJavaScript(
        "return arguments[0].selectedOptions[arguments[1]]", selectElement.getWebElement(), index
      ));
    }

    @Override
    public String getSearchCriteria() {
      return selectElement.description() + " selected options";
    }

    @Override
    public String toString() {
      return selectElement + " selected options";
    }

    @Override
    public Driver driver() {
      return selectElement.driver();
    }

    @Override
    public Alias getAlias() {
      return alias;
    }

    @Override
    public void setAlias(String alias) {
      this.alias = new Alias(alias);
    }
  }
}
